==> jc-1.4.0.tar.gz: java/io/PipedWriter.h <==
// public class java.io.PipedWriter

// class file dependencies
// @dep_class 9164dff74929beb4 java_io_PipedWriter
// @dep_class 4897ee169f60a14f java_io_Writer
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_io_Writer

#include "java/io/Writer.h"

#ifndef _JC_java_io_PipedWriter_H_
#define _JC_java_io_PipedWriter_H_

// Forward structure declarations
struct _jc_java_io_PipedReader$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_java_io_PipedWriter$sub_refs	_jc_java_io_PipedWriter$sub_refs;
typedef struct _jc_java_io_PipedWriter$sub_nonrefs	_jc_java_io_PipedWriter$sub_nonrefs;
typedef struct _jc_java_io_PipedWriter$refs	_jc_java_io_PipedWriter$refs;
typedef struct _jc_java_io_PipedWriter$nonrefs	_jc_java_io_PipedWriter$nonrefs;
typedef struct _jc_java_io_PipedWriter$object	_jc_java_io_PipedWriter$object;

typedef const struct _jc_java_io_PipedWriter$vmethods	_jc_java_io_PipedWriter$vmethods;
typedef const struct _jc_java_io_PipedWriter$vtable	_jc_java_io_PipedWriter$vtable;
typedef const struct _jc_java_io_PipedWriter$vtype	_jc_java_io_PipedWriter$vtype;

// Constructors
extern void _jc_java_io_PipedWriter$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_io_PipedWriter$object *);
extern void _jc_java_io_PipedWriter$method$_init$4a12d00e1fb0b2ba(_jc_env *, struct _jc_java_io_PipedWriter$object *, struct _jc_java_io_PipedReader$object *);

// Virtual methods
extern void _jc_java_io_PipedWriter$method$close$6aba8b329fddcd79(_jc_env *, struct _jc_java_io_PipedWriter$object *);
extern void _jc_java_io_PipedWriter$method$connect$d5716731c01f205e(_jc_env *, struct _jc_java_io_PipedWriter$object *, struct _jc_java_io_PipedReader$object *);
extern void _jc_java_io_PipedWriter$method$flush$9dedb7d85e88cf56(_jc_env *, struct _jc_java_io_PipedWriter$object *);
extern void _jc_java_io_PipedWriter$method$this$adc93fb6bf4cbffa(_jc_env *, struct _jc_java_io_PipedWriter$object *);
extern void _jc_java_io_PipedWriter$method$write$6377ac6964854eb2(_jc_env *, struct _jc_java_io_PipedWriter$object *, jint);
extern void _jc_java_io_PipedWriter$method$write$dc4877c8c0adbc0a(_jc_env *, struct _jc_java_io_PipedWriter$object *, struct _jc_char_array *, jint, jint);

// Virtual method descriptors
extern _jc_method _jc_java_io_PipedWriter$method_info$close$6aba8b329fddcd79;
extern _jc_method _jc_java_io_PipedWriter$method_info$connect$d5716731c01f205e;
extern _jc_method _jc_java_io_PipedWriter$method_info$flush$9dedb7d85e88cf56;
extern _jc_method _jc_java_io_PipedWriter$method_info$this$adc93fb6bf4cbffa;
extern _jc_method _jc_java_io_PipedWriter$method_info$write$6377ac6964854eb2;
extern _jc_method _jc_java_io_PipedWriter$method_info$write$dc4877c8c0adbc0a;

// Virtual methods structure
struct _jc_java_io_PipedWriter$vmethods {
	void	(*close$6aba8b329fddcd79)(_jc_env *, struct _jc_java_io_PipedWriter$object *);
	void	(*connect$d5716731c01f205e)(_jc_env *, struct _jc_java_io_PipedWriter$object *, struct _jc_java_io_PipedReader$object *);
	void	(*flush$9dedb7d85e88cf56)(_jc_env *, struct _jc_java_io_PipedWriter$object *);
	void	(*this$adc93fb6bf4cbffa)(_jc_env *, struct _jc_java_io_PipedWriter$object *);
	void	(*write$6377ac6964854eb2)(_jc_env *, struct _jc_java_io_PipedWriter$object *, jint);
	void	(*write$dc4877c8c0adbc0a)(_jc_env *, struct _jc_java_io_PipedWriter$object *, struct _jc_char_array *, jint, jint);
};

// Vtable
struct _jc_java_io_PipedWriter$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_io_Writer$vmethods	java_io_Writer;
	_jc_java_io_PipedWriter$vmethods	java_io_PipedWriter;
};

// Vtype
struct _jc_java_io_PipedWriter$vtype {
	_jc_type			type;
	_jc_java_io_PipedWriter$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_io_PipedWriter$sub_refs {
	struct _jc_java_io_PipedReader$object	*sink;
	_jc_char_array	*read__5fbuf;
};

// Reference instance fields (object)
struct _jc_java_io_PipedWriter$refs {
    _jc_java_io_PipedWriter$sub_refs	java_io_PipedWriter;
    _jc_java_io_Writer$sub_refs	java_io_Writer;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_io_PipedWriter$sub_nonrefs {
	jboolean	closed;
};

// Non-reference instance fields (object)
struct _jc_java_io_PipedWriter$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_io_Writer$sub_nonrefs	java_io_Writer;
    _jc_java_io_PipedWriter$sub_nonrefs	java_io_PipedWriter;
};

// Object instance structure
struct _jc_java_io_PipedWriter$object {
	_jc_java_io_PipedWriter$refs	refs[0];
	_jc_word		lockword;
	_jc_java_io_PipedWriter$vtype	*vtype;
	_jc_java_io_PipedWriter$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_io_PipedWriter$vtype _jc_java_io_PipedWriter$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_io_PipedWriter, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_io_PipedWriter$class_object;

#endif	/* _JC_java_io_PipedWriter_H_ */

==> jc-1.4.6.tar.gz: java/io/PipedWriter.h <==
// public class java.io.PipedWriter

// class file dependencies
// @dep_class 9164dff74929beb4 java_io_PipedWriter
// @dep_class 4897ee169f60a14f java_io_Writer
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_io_Writer

#include "java/io/Writer.h"

#ifndef _JC_java_io_PipedWriter_H_
#define _JC_java_io_PipedWriter_H_

// Forward structure declarations
struct _jc_java_io_PipedReader$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_java_io_PipedWriter$sub_refs	_jc_java_io_PipedWriter$sub_refs;
typedef struct _jc_java_io_PipedWriter$sub_nonrefs	_jc_java_io_PipedWriter$sub_nonrefs;
typedef struct _jc_java_io_PipedWriter$refs	_jc_java_io_PipedWriter$refs;
typedef struct _jc_java_io_PipedWriter$nonrefs	_jc_java_io_PipedWriter$nonrefs;
typedef struct _jc_java_io_PipedWriter$object	_jc_java_io_PipedWriter$object;

typedef const struct _jc_java_io_PipedWriter$vmethods	_jc_java_io_PipedWriter$vmethods;
typedef const struct _jc_java_io_PipedWriter$vtable	_jc_java_io_PipedWriter$vtable;
typedef const struct _jc_java_io_PipedWriter$vtype	_jc_java_io_PipedWriter$vtype;

// Constructors
extern void _jc_java_io_PipedWriter$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_io_PipedWriter$object *) _JC_JCNI_ATTR;
extern void _jc_java_io_PipedWriter$method$_init$4a12d00e1fb0b2ba(_jc_env *, struct _jc_java_io_PipedWriter$object *, struct _jc_java_io_PipedReader$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_java_io_PipedWriter$method$close$6aba8b329fddcd79(_jc_env *, struct _jc_java_io_PipedWriter$object *) _JC_JCNI_ATTR;
extern void _jc_java_io_PipedWriter$method$connect$d5716731c01f205e(_jc_env *, struct _jc_java_io_PipedWriter$object *, struct _jc_java_io_PipedReader$object *) _JC_JCNI_ATTR;
extern void _jc_java_io_PipedWriter$method$flush$9dedb7d85e88cf56(_jc_env *, struct _jc_java_io_PipedWriter$object *) _JC_JCNI_ATTR;
extern void _jc_java_io_PipedWriter$method$this$adc93fb6bf4cbffa(_jc_env *, struct _jc_java_io_PipedWriter$object *) _JC_JCNI_ATTR;
extern void _jc_java_io_PipedWriter$method$write$6377ac6964854eb2(_jc_env *, struct _jc_java_io_PipedWriter$object *, jint) _JC_JCNI_ATTR;
extern void _jc_java_io_PipedWriter$method$write$dc4877c8c0adbc0a(_jc_env *, struct _jc_java_io_PipedWriter$object *, struct _jc_char_array *, jint, jint) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_io_PipedWriter$method_info$close$6aba8b329fddcd79;
extern _jc_method _jc_java_io_PipedWriter$method_info$connect$d5716731c01f205e;
extern _jc_method _jc_java_io_PipedWriter$method_info$flush$9dedb7d85e88cf56;
extern _jc_method _jc_java_io_PipedWriter$method_info$this$adc93fb6bf4cbffa;
extern _jc_method _jc_java_io_PipedWriter$method_info$write$6377ac6964854eb2;
extern _jc_method _jc_java_io_PipedWriter$method_info$write$dc4877c8c0adbc0a;

// Virtual methods structure
struct _jc_java_io_PipedWriter$vmethods {
	void	(*close$6aba8b329fddcd79)(_jc_env *, struct _jc_java_io_PipedWriter$object *) _JC_JCNI_ATTR;
	void	(*connect$d5716731c01f205e)(_jc_env *, struct _jc_java_io_PipedWriter$object *, struct _jc_java_io_PipedReader$object *) _JC_JCNI_ATTR;
	void	(*flush$9dedb7d85e88cf56)(_jc_env *, struct _jc_java_io_PipedWriter$object *) _JC_JCNI_ATTR;
	void	(*this$adc93fb6bf4cbffa)(_jc_env *, struct _jc_java_io_PipedWriter$object *) _JC_JCNI_ATTR;
	void	(*write$6377ac6964854eb2)(_jc_env *, struct _jc_java_io_PipedWriter$object *, jint) _JC_JCNI_ATTR;
	void	(*write$dc4877c8c0adbc0a)(_jc_env *, struct _jc_java_io_PipedWriter$object *, struct _jc_char_array *, jint, jint) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_io_PipedWriter$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_io_Writer$vmethods	java_io_Writer;
	_jc_java_io_PipedWriter$vmethods	java_io_PipedWriter;
};

// Vtype
struct _jc_java_io_PipedWriter$vtype {
	_jc_type			type;
	_jc_java_io_PipedWriter$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_io_PipedWriter$sub_refs {
	struct _jc_java_io_PipedReader$object	*sink;
	_jc_char_array	*read__5fbuf;
};

// Reference instance fields (object)
struct _jc_java_io_PipedWriter$refs {
    _jc_java_io_PipedWriter$sub_refs	java_io_PipedWriter;
    _jc_java_io_Writer$sub_refs	java_io_Writer;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_io_PipedWriter$sub_nonrefs {
	jboolean	closed;
};

// Non-reference instance fields (object)
struct _jc_java_io_PipedWriter$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_io_Writer$sub_nonrefs	java_io_Writer;
    _jc_java_io_PipedWriter$sub_nonrefs	java_io_PipedWriter;
};

// Object instance structure
struct _jc_java_io_PipedWriter$object {
	_jc_java_io_PipedWriter$refs	refs[0];
	_jc_word		lockword;
	_jc_java_io_PipedWriter$vtype	*vtype;
	_jc_java_io_PipedWriter$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_io_PipedWriter$vtype _jc_java_io_PipedWriter$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_io_PipedWriter, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_io_PipedWriter$class_object;

#endif	/* _JC_java_io_PipedWriter_H_ */
